@@ -1,4 +1,3 @@
-from assesment_creator.logger import logger
 from assesment_creator.cutom_exception import InvalidURLException
 from assesment_creator.helper import output_file, create_docx
 from ensure import ensure_annotations
@@ -20,7 +19,12 @@ def get_data(link: str) -> list:
     content = str(content)
     mixed_pattern = r'M7eMe">(.*?)\<|auto">(.*?)\<\/span>'
     qno_list = re.findall(mixed_pattern, content)
-    return qno_list
+    if len(qno_list)==0:
+        raise InvalidURLException(
+                    "No data found! Please check the link provided"
+                )
+    else:
+        return qno_list
 
 
 @ensure_annotations
